==> cloudpos-common-classes-1.3.6-20200420.181540-16.jar: com/floreantpos/extension/cardconnect/SecuredConstants.java <==
package com.floreantpos.extension.cardconnect;

public class SecuredConstants {
	public static final String IPP320_URL_TEST_CONNECTION = "/cardconnect/rest/"; //$NON-NLS-1$
	public static final String IPP320_URL_AUTH = "/cardconnect/rest/auth"; //$NON-NLS-1$
	public static final String IPP320_URL_CAPTURE = "/cardconnect/rest/capture"; //$NON-NLS-1$
	public static final String IPP320_URL_VOID = "/cardconnect/rest/void"; //$NON-NLS-1$
	public static final String IPP320_URL_REFUND = "/cardconnect/rest/refund"; //$NON-NLS-1$

	public static final String IPP320_USERNAME = "ipp320.username"; //$NON-NLS-1$
	public static final String IPP320_PASSWORD = "ipp320.password"; //$NON-NLS-1$
	public static final String IPP320_MERCHANTID = "ipp320.merchantid"; //$NON-NLS-1$

	public static final String PROP_IPP320_RESPSTAT = "respstat"; //$NON-NLS-1$
	public static final String PROP_IPP320_ACCOUNT = "account"; //$NON-NLS-1$
	public static final String PROP_IPP320_TOKEN = "token"; //$NON-NLS-1$
	public static final String PROP_IPP320_RETREF = "retref"; //$NON-NLS-1$
	public static final String PROP_IPP320_AMOUNT = "amount"; //$NON-NLS-1$
	public static final String PROP_IPP320_MERCHID = "merchid"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPCODE = "respcode"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPTEXT = "resptext"; //$NON-NLS-1$
	public static final String PROP_IPP320_AVSRESP = "avsresp"; //$NON-NLS-1$
	public static final String PROP_IPP320_CVVRESP = "cvvresp"; //$NON-NLS-1$
	public static final String PROP_IPP320_AUTHCODE = "authcode"; //$NON-NLS-1$
	public static final String PROP_IPP320_FNOR = "FNOR"; //$NON-NLS-1$
	public static final String PROP_IPP320_EMV = "emv"; //$NON-NLS-1$
	public static final String PROP_IPP320_SETLSTAT = "setlstat"; //$NON-NLS-1$
	public static final String PROP_IPP320_COMMCARD = "commcard"; //$NON-NLS-1$
	public static final String PROP_IPP320_BATCHID = "batchid"; //$NON-NLS-1$
	public static final String PROP_IPP320_CURRENCY = "currency"; //$NON-NLS-1$
	public static final String PROP_IPP320_ORDERID = "orderid"; //$NON-NLS-1$
	public static final String PROP_IPP320_CAPTURE = "capture"; //$NON-NLS-1$
	public static final String PROP_IPP320_TOKENIZE = "tokenize"; //$NON-NLS-1$
	public static final String PROP_IPP320_TRACK = "track"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPPROC = "respproc"; //$NON-NLS-1$
	public static final String PROP_IPP320_EXPIRY = "expiry"; //$NON-NLS-1$
	public static final String PROP_IPP320_CVV2 = "cvv2"; //$NON-NLS-1$
	public static final String PROP_IPP320_NAME = "name"; //$NON-NLS-1$

	public static final String PROP_IPP320_RESPSTAT_APPROVED = "A"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPSTAT_RETRY = "B"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPSTAT_DECLINED = "C"; //$NON-NLS-1$
	public static final String HOST_URL = "securedHostURL"; //$NON-NLS-1$
	public static final String ONLINEORDER_CARDCONNECT_HOSTSYSTEM = "menugreat.cardconnect.hostsystem";
	public static final String ONLINEORDER_CARDCONNECT_MERCHANT_ID = "menugreat.cardconnect.merchantId";
	public static final String ONLINEORDER_CARDCONNECT_USERNAME = "menugreat.cardconnect.username";
	public static final String ONLINEORDER_CARDCONNECT_PASSWORD = "menugreat.cardconnect.password";
}

==> cloudpos-common-classes-1.7-20210730.092436-280.jar: com/floreantpos/extension/cardconnect/SecuredConstants.java <==
package com.floreantpos.extension.cardconnect;

public class SecuredConstants {
	public static final String IPP320_URL_TEST_CONNECTION = "/cardconnect/rest/"; //$NON-NLS-1$
	public static final String IPP320_URL_AUTH = "/cardconnect/rest/auth"; //$NON-NLS-1$
	public static final String IPP320_URL_CAPTURE = "/cardconnect/rest/capture"; //$NON-NLS-1$
	public static final String IPP320_URL_VOID = "/cardconnect/rest/void"; //$NON-NLS-1$
	public static final String IPP320_URL_REFUND = "/cardconnect/rest/refund"; //$NON-NLS-1$
	public static final String IPP320_URL_CARD = "/cardconnect/rest/profile"; //$NON-NLS-1$

	public static final String IPP320_USERNAME = "ipp320.username"; //$NON-NLS-1$
	public static final String IPP320_PASSWORD = "ipp320.password"; //$NON-NLS-1$
	public static final String IPP320_MERCHANTID = "ipp320.merchantid"; //$NON-NLS-1$

	public static final String PROP_IPP320_RESPSTAT = "respstat"; //$NON-NLS-1$
	public static final String PROP_IPP320_ACCOUNT = "account"; //$NON-NLS-1$
	public static final String PROP_IPP320_TOKEN = "token"; //$NON-NLS-1$
	public static final String PROP_IPP320_RETREF = "retref"; //$NON-NLS-1$
	public static final String PROP_IPP320_AMOUNT = "amount"; //$NON-NLS-1$
	public static final String PROP_IPP320_MERCHID = "merchid"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPCODE = "respcode"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPTEXT = "resptext"; //$NON-NLS-1$
	public static final String PROP_IPP320_AVSRESP = "avsresp"; //$NON-NLS-1$
	public static final String PROP_IPP320_CVVRESP = "cvvresp"; //$NON-NLS-1$
	public static final String PROP_IPP320_AUTHCODE = "authcode"; //$NON-NLS-1$
	public static final String PROP_IPP320_FNOR = "FNOR"; //$NON-NLS-1$
	public static final String PROP_IPP320_EMV = "emv"; //$NON-NLS-1$
	public static final String PROP_IPP320_SETLSTAT = "setlstat"; //$NON-NLS-1$
	public static final String PROP_IPP320_COMMCARD = "commcard"; //$NON-NLS-1$
	public static final String PROP_IPP320_BATCHID = "batchid"; //$NON-NLS-1$
	public static final String PROP_IPP320_CURRENCY = "currency"; //$NON-NLS-1$
	public static final String PROP_IPP320_ORDERID = "orderid"; //$NON-NLS-1$
	public static final String PROP_IPP320_CAPTURE = "capture"; //$NON-NLS-1$
	public static final String PROP_IPP320_TOKENIZE = "tokenize"; //$NON-NLS-1$
	public static final String PROP_IPP320_TRACK = "track"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPPROC = "respproc"; //$NON-NLS-1$
	public static final String PROP_IPP320_EXPIRY = "expiry"; //$NON-NLS-1$
	public static final String PROP_IPP320_CVV2 = "cvv2"; //$NON-NLS-1$
	public static final String PROP_IPP320_NAME = "name"; //$NON-NLS-1$
	public static final String PROP_IPP320_ACCTTYPE = "accttype"; //$NON-NLS-1$
	public static final String PROP_IPP320_PROFILEID = "profileid"; //$NON-NLS-1$
	public static final String PROP_IPP320_ACCTID = "acctid"; //$NON-NLS-1$

	public static final String PROP_IPP320_RESPSTAT_APPROVED = "A"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPSTAT_RETRY = "B"; //$NON-NLS-1$
	public static final String PROP_IPP320_RESPSTAT_DECLINED = "C"; //$NON-NLS-1$
	public static final String HOST_URL = "securedHostURL"; //$NON-NLS-1$
	public static final String ONLINEORDER_CARDCONNECT_HOSTSYSTEM = "menugreat.cardconnect.hostsystem"; //$NON-NLS-1$
	public static final String ONLINEORDER_CARDCONNECT_MERCHANT_ID = "menugreat.cardconnect.merchantId"; //$NON-NLS-1$
	public static final String ONLINEORDER_CARDCONNECT_USERNAME = "menugreat.cardconnect.username"; //$NON-NLS-1$
	public static final String ONLINEORDER_CARDCONNECT_PASSWORD = "menugreat.cardconnect.password"; //$NON-NLS-1$

	public static final String PROFILEID = "secured.profileid"; //$NON-NLS-1$
}
